<?xml version="1.0" ?><!DOCTYPE TS><TS language="ky" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Браузердин тышында да өмүр бар!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Нуска %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Лицензиянын ээси: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 — бекер программалык жабдык, бирок анын иштетүүсү көп убагымды алат.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>%2&apos;га &lt;a href=&apos;%1&apos;&gt;тартуу кылып&lt;/a&gt; мындан аркы иштетүүсүн колдоп бериңиз.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>%2 аркылуу %1&apos;ду өз эне тилиңизге которуңуз</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Иконканын автору %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; шартында чыгарылган</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Жабуу</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Программа тууралуу</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Лицензиялык маалыматтарыңызды киргизиңиз</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Эл. почта:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>%1 лицензиялап алыңыз</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Демострациялоо мөөнөтү бүттү.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Лицензиясыз болгондуктан, тиркеменин мөөнөтү %1 күндөн кийин бүтөт.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Толук версиясын алсаңыз, %1 үчүн оор жумуш кылып жатканымды да колдоп бере аласыз.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Демону колдонуу</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Лицензияны киргизиңиз</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Лицензияны сатып алуу</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>%1 тарабынан</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Бардык видеолор</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Көрүлбөгөн видеолор</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Аты</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Соңку жаңылангандар</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Соңку кошулгандар</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Соңку көрүлгөндөр</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Эң көп көрүлгөндөр</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сорттоо</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Баарын көрүлдү деп белгилөө</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Жаңыланганын көрсөтүү</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Сизде жазылуулар жок. Каналдарга жазылуу үчүн жылдызча символун колдонуңуз.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Бардык видеолор</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Көрүлбөгөн видеолор</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Учурда жаңыланган жазылуулар жок.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 көрүү</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>байт/сек</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>КБ/сек</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>МБ/сек</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунда</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>минута</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 калды</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%2 жерине %1 файлы жүктөлдү</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Жүктөп алуу аякталды</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Жайгашкан жерин өзгөртүү...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Жүктөп алуу жерин тандоо</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Жүктөп алуу жери өзгөртүлдү.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Кезекте жүктөлүп жаткандар мурунку жерге сакталат.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>%1 папкасына жүктөлүүдө</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Жүктөөлөр</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Ойнотуу</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Бир азга токтотуу</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Ойнотуу/Бир азга токтотуу</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Токтотуу</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Кезектеги жолчодон кийин ойнотууну токтотуу</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Кийинки жолчо</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Мурунку жолчо</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Көлөмүн чоңойтуу</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Көлөмүн азайтуу</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Үнүн өчүрүү</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Алга түрүү</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Артка түрүү</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Издөө</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Ачкыч сөз менен видеолорду жана каналдарды табыңыз</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Сереп</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Видеолорду категориясы боюнча кароо</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Жазылуулар</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Канал жазылуулары</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Өз үйүңүздөгүдөй болуңуз</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Түрүү</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Токтотуу</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Ойнотууну токтотуп издөө көрүнүшүнө кайтуу</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Мурунку</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Мурунку жолчого кайтуу</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Ө&amp;ткөрүү</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Кийинки видеого өтүү</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Ойнотуу</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Ойнотууну улантуу</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Толук экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Толук экранга өтүү</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Тыгыз режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ойнотуу тизмесин жана аспап панелин жашыруу</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>&amp;YouTube барагын ачуу</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Видеонун YouTube барагына өтүү жана ойнотууну бир азга токтотуу</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube &amp;шилтемесин көчүрүү</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Кезектеги видеонун YouTube шилтемесин алмашуу буферине көчүрүү</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Видео агымдын &amp;шилтемесин көчүрүү</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Кезектеги видео агымдын дарегин алмашуу буферине көчүрүү</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Видео&amp;фрагменттерди табуу</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Видеонун башка бөлүктөрүн үмүт кылып туура ирети менен табуу</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Ө&amp;чүрүү</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Ойнотуу тизмесиндеги тандалган видеолорду өчүрүү</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Ө&amp;йдө</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Ойнотуу тизмесиндеги тандалган видеолорду өйдө жылдыруу</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Ылдый</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Ойнотуу тизмесиндеги тандалган видеолорду ылдый жылдыруу</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Соңку издөөлөрдү &amp;тазалоо</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Издөө тарыхын тазалоо. Өзгөртүүлөр кайталанбас.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Чыгуу</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Кош болуңуз</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб-сайт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 интернетте</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Тартуу кылуу</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1&apos;дун мындан аркы иштетүүсүн колдоп бериңиз</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Программа &amp;жөнүндө</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1 жөнүндө маалымат</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Издөө</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Үндү өчүрүү</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Ойнотууну &amp;кол менен баштатуу</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Видео ойнотууну кол менен баштатуу</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Жүктөөлөр</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Видео жүктөөлөрү жөнүндө кошумча маалымат көрсөтүү</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Жүктөп алуу</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Кезектеги видеону жүктөп алуу</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>Каналга &amp;жазылуу</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Учурдагы видеону %1 аркылуу бөлүшүү</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Эл. почта</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Эл. почта</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Жабуу</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Үстүнөн &amp;калкытуу</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Бул видеодон кийин &amp;токтотуу</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Катаны &amp;маалымдоо...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>Издөөнү &amp;тактоо...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Дагы...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Байланыштуу видеолор</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Кезектегиге байланыштуу видеону көрүү</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>&amp;Браузерден ачуу...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1&apos;ду сатып алуу...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Тиркеме</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Ойнотуу</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Ойнотуу &amp;тизмеси</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видео</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Бөлүшүү</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Көрүнүш</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Жардам</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Көлөмүн чоңойтуу үчүн %1 комбинациясын басыңыз, кичирейтүү үчүн %2</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Мазмундун жайгашкан жерин тандаңыз</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 ачылууда</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Жүктөп алуу болуп жаткан кезде %1&apos;дан чыгууну каалайсызбы?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Эгер сиз %1&apos;ду азыр жапсаңыз, бул жүктөө жокко чыгарылат.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Жабуу жана жүктөөнү жокко чыгаруу</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Жүктөп алуунун аяктоосун күтүү</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ката: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Бир азга токтотуу</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Ойнотууну бир азга токтотуу</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Толук экрандан чыгуу</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Калган убагы: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Көлөмү %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Үнү өчүрүлдү</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Үнү күйгүзүлдү</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Видеонун жогорку чечими: %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Жашырындуулугуңуз камсыздалды</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Жүктөлөр аякталды</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версия %2 азыр жеткиликтүү.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Кечирээк эске салуу</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Жаңылоо</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>YouTube&apos;дун дарегин эми башка тиркемеге койсоңуз болот</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Видео агымдын дарегин эми башка тиркемеге койсоңуз болот</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Чакан убакытка чейин гана шилтеме анык болот.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1 жүктөп алынууда</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>/</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>бөлүк</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>эпизод</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>%1 жеринен жөнөтүү</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>%1 каналындагы жазылуудан чыгуу</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>%1 каналына жазылуу</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1&apos;дун жаңы версиясы жеткиликтүү!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 азыр жеткиликтүү. Сизде %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Азыр жүктөп алгыңыз келеби?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Бул версияны өткөрүү</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Кечирээк эске салдыруу</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Жаңылоону орнотуу</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Коюу</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 / %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Даярдалууда</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ката</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Аякталды</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Токтотулду</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Жүктөп алууну токтотуу</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>%1 жеринен көрсөтүү</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Ата-эне каталогун ачуу</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Жүктөп алууну кайтадан жүргүзүү</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Дагы %1 видеону көрсөтүү</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Видеолор жок</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Дагы видеолор жок</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Сорттоо</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Релеванттуулук</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Көрүү саны</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Рейтинг</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Каалаган убакта</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Бүгүн</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 күн</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 күн</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Узактык</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Баары</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Кыска</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Орточо</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Узак</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>4 минутадан кыскараак</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4 менен 20 минутанын арасынан</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>20 минутадан узагыраак</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Сапат</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Жогорку чечим</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p же жогору</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Даяр</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Даяр</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Издөө</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;га кош келиңиз,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>менен табып көрүү.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ачкыч сөз</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Видеолорду</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Соңку ачкыч сөздөр</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Соңку каналдар</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Толук версиясын сатып алуу</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Артка</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>%1 алга</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>%1 видеосуна кайтуу</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Издөөнү тактоо</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Бул эмеспи: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Жайгашкан жерин өзгөртүү...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Эң популярдуу</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Жаңылоолор жүктөп алынууда...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Алжир</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Аргентина</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Австралия</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Белгия</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Бразилия</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Чили</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Колумбия</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Чехия</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Египт</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Франция</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Германия</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Гана</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Греция</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Гонконг</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Венгрия</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Индия</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Индонезия</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ирландия</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Израиль</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Италия</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Япония</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Иордан</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Кения</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Малайзия</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Мексика</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Марокко</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Нидерланддар</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Жаңы Зеландия</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Нигерия</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Филиппиндер</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Польша</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Орусия</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Сауд Аравиясы</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Сингапур</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Түштүк Африка</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Түштүк Корея</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Испания</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Швеция</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Тайвань</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Тунис</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Түркия</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Уганда</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Бириккен Араб Эмираттары</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Улуу Британия</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Йемен</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Бүткүл дүйнө</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>%1 үчүн видео агымын алуу мүмкүн эмес</translation>
    </message>
</context>
</TS>